import * as React from 'react';
import { Plugin, RenderViewer, Viewer } from '@react-pdf-viewer/core';
import { thumbnailPlugin } from '@react-pdf-viewer/thumbnail';

interface PageThumbnailPluginProps {
    PageThumbnail: React.ReactElement;
}

const pageThumbnailPlugin = (props: PageThumbnailPluginProps): Plugin => {
    const { PageThumbnail } = props;

    return {
        renderViewer: (renderProps: RenderViewer) => {
            let { slot } = renderProps;

            slot.children = PageThumbnail;

            // Reset the sub slot
            slot.subSlot.attrs = {};
            slot.subSlot.children = <></>;

            return slot;
        },
    };
};

const ThumbnailCover: React.FC<{
    fileUrl: string;
}> = ({ fileUrl }) => {
    const thumbnailPluginInstance = thumbnailPlugin();
    const { Cover } = thumbnailPluginInstance;
    const pageThumbnailPluginInstance = pageThumbnailPlugin({
        PageThumbnail: <Cover getPageIndex={() => 0} />,
    });

    return <Viewer fileUrl={fileUrl} plugins={[pageThumbnailPluginInstance, thumbnailPluginInstance]} />;
};

const IndexPage = () => (
    <div>
        <div
            data-testid="first-doc-cover"
            style={{
                border: '1px solid rgba(0, 0, 0, 0.3)',
                height: '20rem',
                margin: '5rem auto',
                width: '20rem',
            }}
        >
            <ThumbnailCover fileUrl="/pdf-open-parameters.pdf" />
        </div>
        <div
            data-testid="second-doc-cover"
            style={{
                border: '1px solid rgba(0, 0, 0, 0.3)',
                height: '20rem',
                margin: '5rem auto',
                width: '20rem',
            }}
        >
            <ThumbnailCover fileUrl="/sample.pdf" />
        </div>
    </div>
);

export default IndexPage;
